@@ -7,6 +7,7 @@ static const char PJ_LIST_H_ID[] = "@(#)pj_list.h	4.5	95/08/09	GIE	REL";
 */
 PROJ_HEAD(aea, "Albers Equal Area")
 PROJ_HEAD(aeqd, "Azimuthal Equidistant")
+PROJ_HEAD(affine, "Affine transformation")
 PROJ_HEAD(airy, "Airy")
 PROJ_HEAD(aitoff, "Aitoff")
 PROJ_HEAD(alsk, "Mod. Stererographics of Alaska")
@@ -14,6 +15,7 @@ PROJ_HEAD(apian, "Apian Globular I")
 PROJ_HEAD(august, "August Epicycloidal")
 PROJ_HEAD(axisswap, "Axis ordering")
 PROJ_HEAD(bacon, "Bacon Globular")
+PROJ_HEAD(bertin1953, "Bertin 1953")
 PROJ_HEAD(bipc, "Bipolar conic of western hemisphere")
 PROJ_HEAD(boggs, "Boggs Eumorphic")
 PROJ_HEAD(bonne, "Bonne (Werner lat_1=90)")
@@ -36,7 +38,7 @@ PROJ_HEAD(eck4, "Eckert IV")
 PROJ_HEAD(eck5, "Eckert V")
 PROJ_HEAD(eck6, "Eckert VI")
 PROJ_HEAD(eqearth, "Equal Earth")
-PROJ_HEAD(eqc, "Equidistant Cylindrical (Plate Caree)")
+PROJ_HEAD(eqc, "Equidistant Cylindrical (Plate Carree)")
 PROJ_HEAD(eqdc, "Equidistant Conic")
 PROJ_HEAD(euler, "Euler")
 PROJ_HEAD(etmerc, "Extended Transverse Mercator" )
@@ -46,6 +48,7 @@ PROJ_HEAD(fouc_s, "Foucaut Sinusoidal")
 PROJ_HEAD(gall, "Gall (Gall Stereographic)")
 PROJ_HEAD(geoc, "Geocentric Latitude")
 PROJ_HEAD(geocent, "Geocentric")
+PROJ_HEAD(geogoffset, "Geographic Offset")
 PROJ_HEAD(geos, "Geostationary Satellite View")
 PROJ_HEAD(gins8, "Ginsburg VIII (TsNIIGAiK)")
 PROJ_HEAD(gn_sinu, "General Sinusoidal Series")
@@ -91,6 +94,7 @@ PROJ_HEAD(mil_os, "Miller Oblated Stereographic")
 PROJ_HEAD(mill, "Miller Cylindrical")
 PROJ_HEAD(misrsom, "Space oblique for MISR")
 PROJ_HEAD(moll, "Mollweide")
+PROJ_HEAD(molobadekas, "Molodensky-Badekas transform") /* implemented in PJ_helmert.c */
 PROJ_HEAD(molodensky, "Molodensky transform")
 PROJ_HEAD(murd1, "Murdoch I")
 PROJ_HEAD(murd2, "Murdoch II")
@@ -112,6 +116,8 @@ PROJ_HEAD(pconic, "Perspective Conic")
 PROJ_HEAD(patterson, "Patterson Cylindrical")
 PROJ_HEAD(pipeline, "Transformation pipeline manager")
 PROJ_HEAD(poly, "Polyconic (American)")
+PROJ_HEAD(pop, "Retrieve coordinate value from pipeline stack")
+PROJ_HEAD(push, "Save coordinate value on pipeline stack")
 PROJ_HEAD(putp1, "Putnins P1")
 PROJ_HEAD(putp2, "Putnins P2")
 PROJ_HEAD(putp3, "Putnins P3")
@@ -137,6 +143,7 @@ PROJ_HEAD(tcea, "Transverse Cylindrical Equal Area")
 PROJ_HEAD(times, "Times Projection")
 PROJ_HEAD(tissot, "Tissot Conic")
 PROJ_HEAD(tmerc, "Transverse Mercator")
+PROJ_HEAD(tobmerc, "Tobler-Mercator")
 PROJ_HEAD(tpeqd, "Two Point Equidistant")
 PROJ_HEAD(tpers, "Tilted perspective")
 PROJ_HEAD(unitconvert, "Unit conversion")
